/* PAM to automate Uni-Klu login tasks */

/* 
 * Albrecht Gebhardt <agebhard@uni-klu.ac.at>
 * Copyright: GPL, See COPYING.LIB-2.0
 *
 * Created Sun Jun 16 21:12:20 CEST 2002
 * 
 * Version:
 * $Id: pam_linux_uniklu_cleanup_password.c,v 1.5 2009-01-11 15:38:07 agebhard Exp $
 * 
 * Last Revised on
 * $Date: 2009-01-11 15:38:07 $
 * 
 * Changelog:
 *
 * $Log: pam_linux_uniklu_cleanup_password.c,v $
 * Revision 1.5  2009-01-11 15:38:07  agebhard
 * reduce compiler warnings
 *
 * Revision 1.4  2009-01-09 10:17:09  agebhard
 * ...
 *
 * Revision 1.3  2002/06/18 13:25:08  agebhard
 * new debugging. still not working on madrake.
 * pam_sm_authenticate fails because it is called before entereing a password!
 *
 * Revision 1.2  2002/06/17 09:57:28  agebhard
 * more cvs keywords ...
 *
 * 
 */

#include <string.h>
#include <stdlib.h>
#include "pam_linux_uniklu.h"

extern void	pam_linux_uniklu_cleanup_password(pam_handle_t *pamh,
						  void	*data,
						  int	error_status)
{
    static char *procname="pam_linux_uniklu_cleanup_password";

#   ifdef DEBUG 
    syslog(LOG_DEBUG, "%s", procname);
#   endif
    memset(data, '\0', strlen(data));
    free(data);
}
